@@ -108,18 +108,23 @@ class SlappResponseObject:
         return [tup[0] for tup in self.matched_players_for_teams.get(team_guid.__str__(), [])
                 if tup and (tup[1] or include_ex_players)]
 
-    def get_team(self, team_id: Union[str, UUID]) -> Team:
+    def get_teams_from_ids(self, team_ids: Iterable[Union[str, UUID]]) -> List[Team]:
         from slapp_py.core_classes.builtins import NoTeam, UnknownTeam
-        if isinstance(team_id, UUID):
-            t_str = team_id.__str__()
-        elif isinstance(team_id, str):
-            t_str = team_id
-        elif team_id is None:
-            return NoTeam
-        else:
-            assert False, f"Don't know what {team_id} is"
+        result = []
+        for team_id in team_ids:
+            if isinstance(team_id, UUID):
+                t_str = team_id.__str__()
+            elif isinstance(team_id, str):
+                t_str = team_id
+            elif team_id is None:
+                return NoTeam
+            else:
+                assert False, f"Don't know what {team_id} is"
+            result.append(NoTeam if t_str == NoTeam.guid.__str__() else self.known_teams.get(t_str, UnknownTeam))
+        return result
 
-        return NoTeam if t_str == NoTeam.guid.__str__() else self.known_teams.get(t_str, UnknownTeam)
+    def get_team(self, team_id: Union[str, UUID]) -> Team:
+        return self.get_teams_from_ids([team_id])[0]
 
     def get_teams_for_player(self, p: Player) -> List[Team]:
         return [self.get_team(t_uuid) for t_uuid in p.teams]
